---
name: Bug Report
about: Report bugs you notice while using Tern

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Error in terminal**
```
Paste your terminal output here
```

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment you are running Tern on**
Enter all that apply
- Output of 'tern --version'
- Operating System (Linux Distro and version or Mac or Windows)
- Vagrant file
- Container OS
- Python version (3.6 or higher)
- Cloud environment (AWS, Azure, GCP)

**Please attach files if they exist**
- tern.log
- report.*
